"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("./utils");
function getTestConfig({ usesYarn, packagePath, packageData }) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const packages = {};
        const configs = [];
        const command = usesYarn ? 'yarn' : 'npm run';
        const hasTest = utils_1.hasScript(packageData, 'test');
        const hasWatchTest = utils_1.hasScript(packageData, 'watch-test');
        const hasJest = utils_1.hasDependency(packageData, 'jest');
        const isCra = utils_1.hasDependency(packageData, 'react-scripts') && hasTest;
        function appendPluginTerminal(options) {
            configs.push({
                pluginName: 'PluginTerminal',
                options,
            });
            packages['@dash4/plugin-terminal'] = true;
        }
        function appendPluginCodeCoverage() {
            configs.push(Object.assign({ pluginName: 'PluginCodeCoverage' }, (packagePath
                ? {
                    options: {
                        cwd: packagePath,
                    },
                }
                : {})));
            packages['@dash4/plugin-code-coverage'] = true;
        }
        if (!hasTest && !hasWatchTest) {
            return { packages, configs };
        }
        if (isCra) {
            appendPluginTerminal({
                cmd: `${command} test`,
                cwd: packagePath,
                allowedCommands: '<DASH4INNER>jestCommands</DASH4INNER>',
            });
            appendPluginCodeCoverage();
            return { packages, configs };
        }
        if (hasWatchTest && hasJest) {
            appendPluginTerminal({
                cmd: `${command} watch-test`,
                cwd: packagePath,
                allowedCommands: '<DASH4INNER>jestCommands</DASH4INNER>',
            });
            appendPluginCodeCoverage();
            return { packages, configs };
        }
        if (hasWatchTest) {
            appendPluginTerminal({
                cmd: `${command} watch-test`,
                cwd: packagePath,
            });
            appendPluginCodeCoverage();
            return { packages, configs };
        }
        appendPluginCodeCoverage();
        return { packages, configs };
    });
}
exports.getTestConfig = getTestConfig;
//# sourceMappingURL=get-test-config.js.map